@@ -1,4 +1,4 @@
-#' Interpret correlation coefficient
+#' Interpret Correlation Coefficient
 #'
 #' @param r Value or vector of correlation coefficient.
 #' @param rules Can be `"funder2019"` (default), `"gignac2016"`, `"cohen1988"`,
@@ -66,6 +66,7 @@
 #' - Evans, J. D. (1996). Straightforward statistics for the behavioral
 #' sciences. Thomson Brooks/Cole Publishing Co.
 #'
+#' @keywords interpreters
 #' @export
 interpret_r <- function(r, rules = "funder2019", ...) {
   rules <- .match.rules(
@@ -108,3 +109,7 @@ interpret_cramers_v <- interpret_r
 #' @export
 #' @rdname interpret_r
 interpret_rank_biserial <- interpret_r
+
+#' @export
+#' @rdname interpret_r
+interpret_fei <- interpret_r
