@@ -1,15 +1,20 @@
-
 #' @keywords internal
-#' @importFrom stats na.omit complete.cases
 .get_data_2_samples <- function(x, y = NULL, data = NULL,
                                 paired = FALSE, allow_ordered = FALSE,
                                 verbose = TRUE, ...) {
   if (inherits(x, "formula")) {
+    if (isTRUE(paired)) {
+      # This is to be consistent with R>=4.4.0
+      insight::format_error("cannot use 'paired = TRUE' in formula method.")
+    }
+
     # Validate:
     if (length(x) != 3L) {
       insight::format_error(
         "Formula must have one of the following forms:",
-        "\n\ty ~ group,\n\ty ~ 1,\n\tPair(x,y) ~ 1"
+        "          y ~ group   (independent samples)",
+        "          y ~ 1       (one sample)",
+        "  Pair(x,y) ~ 1       (paired samples)"
       )
     }
 
@@ -49,8 +54,9 @@
   if (!is.numeric(x)) {
     insight::format_error("Cannot compute effect size for a non-numeric vector.")
   } else if (inherits(x, "Pair")) {
-    x <- x[, 1] - x[, 2]
-    y <- NULL
+    y <- x[, 2]
+    x <- x[, 1]
+    paired <- TRUE
   }
 
 
@@ -92,6 +98,87 @@
   }
 
 
+  list(x = x, y = y, paired = paired)
+}
+
+#' @keywords internal
+.get_data_paired <- function(x, y = NULL, data = NULL, method,
+                             verbose = TRUE, ...) {
+  if (inherits(x, "formula")) {
+    formula_error <-
+      "Formula must have one of the following forms:
+              y ~ condition | id
+      Pair(x,y) ~ 1"
+
+    # Validate:
+    if (length(x) != 3L) {
+      insight::format_error(formula_error)
+    } else if (length(x[[3]]) == 3L && x[[3]][[1]] == as.name("|")) {
+      # is long
+      x[[3L]][[1L]] <- as.name("+")
+      mf <- .resolve_formula(x, data, ...)
+      mf <- stats::na.omit(mf)
+
+      if (method %in% c("d", "r")) {
+        mf[[2]] <- as.factor(mf[[2]])
+        mf[[3]] <- as.factor(mf[[3]])
+        colnames(mf) <- c("y", "condition", "id")
+        return(mf)
+      }
+
+      if (verbose && any(tapply(mf[[1]], mf[3:2], length) > 1L, na.rm = TRUE)) {
+        insight::format_alert(
+          paste0("The ", method, " standardized difference requires paired data,"),
+          "but data contains more than one observation per design cell.",
+          "Aggregating data using `mean()`."
+        )
+      }
+
+      mf <- tapply(mf[[1]], mf[3:2], mean, na.rm = TRUE)
+      x <- mf[, 1]
+      y <- mf[, 2]
+    } else if (x[[2]][[1]] == as.name("Pair")) {
+      # is Pair (wide)
+      mf <- .resolve_formula(x, data, ...)
+      if (ncol(mf) != 1L) {
+        insight::format_error(formula_error)
+      }
+      x <- mf[[1]]
+    } else {
+      insight::format_error(formula_error)
+    }
+  } else {
+    # Test if they are they are column names
+    x <- .resolve_char(x, data)
+    y <- .resolve_char(y, data)
+  }
+
+  if (inherits(x, "Pair")) {
+    y <- x[, 2]
+    x <- x[, 1]
+  }
+
+  # x should be a numeric vector or a Pair:
+  if (!is.numeric(x) || !is.numeric(y)) {
+    insight::format_error("Cannot compute effect size for a non-numeric vector.")
+  }
+
+  o <- stats::complete.cases(x, y)
+  x <- x[o]
+  y <- y[o]
+
+  if (method == "r") {
+    insight::format_error("d{r} requires replications.")
+  } else if (method == "d") {
+    n <- length(x)
+    data <- data.frame(
+      y = c(x, y),
+      condition = factor(rep(1:2, each = n)),
+      id = factor(rep(seq(n), times = 2))
+    )
+    return(data)
+  }
+
   list(x = x, y = y)
 }
 
@@ -99,7 +186,8 @@
 #' @keywords internal
 .get_data_xtabs <- function(x, y = NULL, p = NULL) {
   # TODO dont rely on chisq.test
-  res <- suppressWarnings(stats::chisq.test(x,
+  res <- suppressWarnings(stats::chisq.test(
+    x,
     y = y,
     p = p,
     correct = FALSE,
@@ -129,7 +217,7 @@
     groups <- mf[[2]]
     if (!is.factor(groups)) groups <- factor(groups)
   } else if (inherits(x, "list")) {
-    groups <- rep(letters[seq_along(x)], sapply(x, length))
+    groups <- rep(letters[seq_along(x)], sapply(x, length)) # nolint
     x <- unsplit(x, groups)
   } else {
     # If they are column names
@@ -162,7 +250,6 @@
 }
 
 #' @keywords internal
-#' @importFrom stats reshape
 .get_data_nested_groups <- function(x, groups = NULL, blocks = NULL, data = NULL,
                                     wide = TRUE, allow_ordered = FALSE,
                                     verbose = TRUE, ...) {
@@ -198,7 +285,7 @@
     x <- as.table(x)
   }
 
-  if (inherits(x, c("table"))) {
+  if (inherits(x, "table")) {
     x <- as.data.frame(x)[, c(3, 2, 1)]
   }
 
@@ -232,7 +319,6 @@
 }
 
 #' @keywords internal
-#' @importFrom stats na.pass reformulate
 .get_data_multivariate <- function(x, y = NULL, data = NULL,
                                    verbose = TRUE, ...) {
   if (inherits(x, "formula")) {
@@ -267,7 +353,7 @@
     insight::format_error("x must be a data frame.")
   }
 
-  if (!all(sapply(x, is.numeric))) {
+  if (!all(vapply(x, is.numeric, TRUE))) {
     insight::format_error("All DVs must be numeric.")
   }
 
@@ -280,7 +366,7 @@
       insight::format_error("y must be a data frame.")
     }
 
-    if (!all(sapply(y, is.numeric))) {
+    if (!all(vapply(y, is.numeric, TRUE))) {
       insight::format_error("All DVs must be numeric.")
     }
 
@@ -303,7 +389,6 @@
 
 
 #' @keywords internal
-#' @importFrom stats model.frame na.pass
 .resolve_formula <- function(formula, data, subset, na.action = stats::na.pass, ...) {
   cl <- match.call(expand.dots = FALSE)
   cl[[1]] <- quote(stats::model.frame)
